summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspolygon_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspolygon_imp.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kjsembed/qtbindings/qcanvaspolygon_imp.cpp b/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
index d735fd7a..4064e3f0 100644
--- a/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvaspolygon_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasPolygonImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -73,7 +73,7 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -86,25 +86,25 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasPolygon pointer from an Object.
*/
-QCanvasPolygon *QCanvasPolygonImp::toQCanvasPolygon( KJS::Object &self )
+TQCanvasPolygon *QCanvasPolygonImp::toQCanvasPolygon( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasPolygon *>( obj );
+ return dynamic_cast<TQCanvasPolygon *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasPolygon" )
+ if ( op->typeName() != "TQCanvasPolygon" )
return 0;
- return op->toNative<QCanvasPolygon>();
+ return op->toNative<TQCanvasPolygon>();
}
/**
@@ -122,7 +122,7 @@ KJS::Object QCanvasPolygonImp::construct( KJS::ExecState *exec, const KJS::List
break;
}
- QString msg = i18n("QCanvasPolygonCons has no constructor with id '%1',").arg(id);
+ TQString msg = i18n("QCanvasPolygonCons has no constructor with id '%1',").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -130,15 +130,15 @@ KJS::Object QCanvasPolygonImp::construct( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasPolygonImp::QCanvasPolygon_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QCanvas *
return KJS::Object();
- QCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the QCanvasPolygon object
+ // We should now create an instance of the TQCanvasPolygon object
- QCanvasPolygon *ret = new QCanvasPolygon(
+ TQCanvasPolygon *ret = new TQCanvasPolygon(
arg0 );
@@ -175,7 +175,7 @@ KJS::Value QCanvasPolygonImp::call( KJS::ExecState *exec, KJS::Object &self, con
break;
}
- QString msg = i18n( "QCanvasPolygonImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasPolygonImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -186,7 +186,7 @@ KJS::Value QCanvasPolygonImp::setPoints_3( KJS::ExecState *exec, KJS::Object &ob
// Unsupported parameter QPointArray
return KJS::Value();
- QPointArray arg0; // Dummy
+ TQPointArray arg0; // Dummy
instance->setPoints(
arg0 );
@@ -86,25 +86,25 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasPolygon pointer from an Object.
+ * Extract a TQCanvasPolygon pointer from an Object.
*/
@@ -130,15 +130,15 @@ KJS::Object QCanvasPolygonImp::construct( KJS::ExecState *exec, const KJS::List
KJS::Object QCanvasPolygonImp::QCanvasPolygon_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();